==> mingw-w64-starpu-1.4.0-2.src.tar.zst: starpu-1.4.0/doc/doxygen_web_languages/html_web_languages/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Language Bindings", "index.html", [
    [ "Organization", "index.html#Organization", null ],
    [ "The StarPU Native Fortran Support", "NativeFortranSupport.html", [
      [ "Implementation Details and Specificities", "NativeFortranSupport.html#NFImplementation", [
        [ "Prerequisites", "NativeFortranSupport.html#NFPrerequisites", null ],
        [ "Configuration", "NativeFortranSupport.html#NFConfiguration", null ],
        [ "Examples", "NativeFortranSupport.html#NFExamples", null ],
        [ "Compiling a Native Fortran Application", "NativeFortranSupport.html#NFAppCompile", null ]
      ] ],
      [ "Fortran Translation for Common StarPU API Idioms", "NativeFortranSupport.html#NFIdioms", null ],
      [ "Uses, Initialization and Shutdown", "NativeFortranSupport.html#NFInitExit", null ],
      [ "Fortran Flavor of StarPU's Variadic Insert_task", "NativeFortranSupport.html#NFInsertTask", null ],
      [ "Functions and Subroutines Expecting Data Structures Arguments", "NativeFortranSupport.html#NFStructs", null ],
      [ "Additional Notes about the Native Fortran Support", "NativeFortranSupport.html#NFNotes", [
        [ "Using StarPU with Older Fortran Compilers", "NativeFortranSupport.html#NFOldFortran", null ],
        [ "Valid API Mixes and Language Mixes", "NativeFortranSupport.html#NFAPIMIX", null ]
      ] ]
    ] ],
    [ "StarPU Java Interface", "StarPUJavaInterface.html", null ],
    [ "Python Interface", "PythonInterface.html", [
      [ "Installation of the Python Interface", "PythonInterface.html#Installation", null ],
      [ "Python Parallelism", "PythonInterface.html#PythonParallelism", null ],
      [ "Using StarPU in Python", "PythonInterface.html#ImplementingStarPUInPython", [
        [ "Submitting Tasks", "PythonInterface.html#SubmittingTasks", null ],
        [ "Returning Future Object", "PythonInterface.html#ReturningFutureObject", null ],
        [ "Submit Python Objects Supporting The Buffer Protocol", "PythonInterface.html#SubmitPythonBuffer", [
          [ "Access Mode Annotation", "PythonInterface.html#AnnotationAccess", null ],
          [ "Methods", "PythonInterface.html#MethodsAcquireRelease", null ]
        ] ]
      ] ],
      [ "StarPU Data Interface for Python Objects", "PythonInterface.html#StarPUPYInterface", [
        [ "Interface for Ordinary Python Objects", "PythonInterface.html#PythonObject", null ],
        [ "Interface for Python Objects Supporting Buffer Protocol", "PythonInterface.html#PythonBuffer", [
          [ "Methods", "PythonInterface.html#Methods", null ]
        ] ],
        [ "Interface for Empty Numpy Array", "PythonInterface.html#EmptyNumpy", null ],
        [ "Array Partitioning", "PythonInterface.html#HandlePartition", null ]
      ] ],
      [ "Benchmark", "PythonInterface.html#Benchmark", null ],
      [ "Running Python Functions as Pipeline Jobs (Imitating Joblib Library)", "PythonInterface.html#ImitatingJoblibLibrary", [
        [ "Examples", "PythonInterface.html#JobLibraryExamples", null ],
        [ "Parallel Parameters", "PythonInterface.html#ParallelParameters", null ],
        [ "Performances", "PythonInterface.html#JobLibPerformances", null ]
      ] ],
      [ "Multiple Interpreters", "PythonInterface.html#MultipleInterpreters", null ],
      [ "Master Slave Support", "PythonInterface.html#StarpupyMasterSlave", null ]
    ] ],
    [ "The StarPU OpenMP Runtime Support (SORS)", "OpenMPRuntimeSupport.html", [
      [ "Implementation Details and Specificities", "OpenMPRuntimeSupport.html#OMPImplementation", [
        [ "Main Thread", "OpenMPRuntimeSupport.html#OMPMainThread", null ],
        [ "Extended Task Semantics", "OpenMPRuntimeSupport.html#OMPTaskSemantics", null ]
      ] ],
      [ "Configuration", "OpenMPRuntimeSupport.html#OMPConfiguration", null ],
      [ "Initialization and Shutdown", "OpenMPRuntimeSupport.html#OMPInitExit", null ],
      [ "Parallel Regions and Worksharing", "OpenMPRuntimeSupport.html#OMPSharing", [
        [ "Parallel Regions", "OpenMPRuntimeSupport.html#OMPParallel", null ],
        [ "Parallel For", "OpenMPRuntimeSupport.html#OMPFor", null ],
        [ "Sections", "OpenMPRuntimeSupport.html#OMPSections", null ],
        [ "Single", "OpenMPRuntimeSupport.html#OMPSingle", null ]
      ] ],
      [ "Tasks", "OpenMPRuntimeSupport.html#OMPTask", [
        [ "Explicit Tasks", "OpenMPRuntimeSupport.html#OMPTaskExplicit", null ],
        [ "Data Dependencies", "OpenMPRuntimeSupport.html#OMPDataDependencies", null ],
        [ "TaskWait and TaskGroup", "OpenMPRuntimeSupport.html#OMPTaskSyncs", null ]
      ] ],
      [ "Synchronization Support", "OpenMPRuntimeSupport.html#OMPSynchronization", [
        [ "Simple Locks", "OpenMPRuntimeSupport.html#OMPSimpleLock", null ],
        [ "Nestable Locks", "OpenMPRuntimeSupport.html#OMPNestableLock", null ],
        [ "Critical Sections", "OpenMPRuntimeSupport.html#OMPCritical", null ],
        [ "Barriers", "OpenMPRuntimeSupport.html#OMPBarrier", null ]
      ] ],
      [ "Example: An OpenMP LLVM Support", "OpenMPRuntimeSupport.html#OMPLLVM", null ],
      [ "OpenMP Standard Functions in StarPU", "OpenMPRuntimeSupport.html#OMPStandard", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"",
"group__API__Bitmap.html#gab47d8b73a23b7dc02735b9b74fc0626b",
"group__API__Codelet__And__Tasks.html#ga6488a63dd85caa7c9853604f6fdc513b",
"group__API__Data__Interfaces.html#abccb7b1d3e85a19d010bec0e2202284f",
"group__API__Data__Interfaces.html#ga833b734aa76cdee89245cb0710793cf9",
"group__API__Data__Interfaces.html#structstarpu__matrix__interface",
"group__API__Data__Partition.html#ga7132923bd901e0e4254cc0b20d49997a",
"group__API__HIP__Extensions.html#ga81c617c18f5cc3e4799fd6858e5c6d3f",
"group__API__Insert__Task.html#ga8be38949dd0489761bd2768f8e584c70",
"group__API__MPI__Support.html#ga35dda88d8fbea13a436d7a8487111cdf",
"group__API__Miscellaneous__Helpers.html#gae86951bac33515af402555de40612711",
"group__API__OpenCL__Extensions.html#ga160dc78c0f6a90b5aa2200b49c5b4d7b",
"group__API__OpenMP__Runtime__Support.html#gaede763d0f3b47343eb1a5e64ceec0062",
"group__API__Perf__Monitoring.html#gae7f82bb64aa7b14bddd6a64289b5ab31",
"group__API__Performance__Model.html#gae91f7c6ecf39a9e510b0b4e51c10f734",
"group__API__SC__Hypervisor.html#ga44f9db8a2a97ebb45f813006c6fbd88f",
"group__API__Scheduling__Contexts.html#ga0afc28558bb1ad29fbfe32d9c51522f8",
"group__API__Standard__Memory__Library.html#ga4e9089680daf0b2d7f26e4657ffe9f48",
"group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e",
"group__API__Workers__Properties.html#gae6166f338640d033b740f5c8008b851b",
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html#a904c891c2a480fbadc2319b208afe259",
"interfacefstarpu__mod_1_1fstarpu__tag__get__task.html#afe36161fddc38b5b82ce7875acb82039",
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__redux__data__prio.html#ab97984b858e7fd137aacf65eac3274ba",
"starpu__config_8h.html#a219c7fdf9de6d6231117ca6a3299c264",
"starpu__thread_8h.html#structstarpu__pthread__queue__t"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_languages/html_web_languages/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Language Bindings", "index.html", [
    [ "The StarPU Native Fortran Support", "NativeFortranSupport.html", [
      [ "Implementation Details and Specificities", "NativeFortranSupport.html#NFImplementation", [
        [ "Prerequisites", "NativeFortranSupport.html#NFPrerequisites", null ],
        [ "Configuration", "NativeFortranSupport.html#NFConfiguration", null ],
        [ "Examples", "NativeFortranSupport.html#NFExamples", null ],
        [ "Compiling a Native Fortran Application", "NativeFortranSupport.html#NFAppCompile", null ]
      ] ],
      [ "Fortran Translation for Common StarPU API Idioms", "NativeFortranSupport.html#NFIdioms", null ],
      [ "Uses, Initialization and Shutdown", "NativeFortranSupport.html#NFInitExit", null ],
      [ "Fortran Flavor of StarPU's Variadic Insert_task", "NativeFortranSupport.html#NFInsertTask", null ],
      [ "Functions and Subroutines Expecting Data Structures Arguments", "NativeFortranSupport.html#NFStructs", null ],
      [ "Additional Notes about the Native Fortran Support", "NativeFortranSupport.html#NFNotes", [
        [ "Using StarPU with Older Fortran Compilers", "NativeFortranSupport.html#NFOldFortran", null ],
        [ "Valid API Mixes and Language Mixes", "NativeFortranSupport.html#NFAPIMIX", null ]
      ] ]
    ] ],
    [ "StarPU Java Interface", "StarPUJavaInterface.html", null ],
    [ "Python Interface", "PythonInterface.html", [
      [ "Installation of the Python Interface", "PythonInterface.html#Installation", null ],
      [ "Python Parallelism", "PythonInterface.html#PythonParallelism", null ],
      [ "Using StarPU in Python", "PythonInterface.html#ImplementingStarPUInPython", [
        [ "Submitting Tasks", "PythonInterface.html#SubmittingTasks", null ],
        [ "Returning Future Object", "PythonInterface.html#ReturningFutureObject", null ],
        [ "Submit Python Objects Supporting The Buffer Protocol", "PythonInterface.html#SubmitPythonBuffer", [
          [ "Access Mode Annotation", "PythonInterface.html#AnnotationAccess", null ],
          [ "Methods", "PythonInterface.html#MethodsAcquireRelease", null ]
        ] ]
      ] ],
      [ "StarPU Data Interface for Python Objects", "PythonInterface.html#StarPUPYInterface", [
        [ "Interface for Ordinary Python Objects", "PythonInterface.html#PythonObject", null ],
        [ "Interface for Python Objects Supporting Buffer Protocol", "PythonInterface.html#PythonBuffer", [
          [ "Methods", "PythonInterface.html#Methods", null ]
        ] ],
        [ "Interface for Empty Numpy Array", "PythonInterface.html#EmptyNumpy", null ],
        [ "Array Partitioning", "PythonInterface.html#HandlePartition", null ]
      ] ],
      [ "Benchmark", "PythonInterface.html#Benchmark", null ],
      [ "Running Python Functions as Pipeline Jobs (Imitating Joblib Library)", "PythonInterface.html#ImitatingJoblibLibrary", [
        [ "Examples", "PythonInterface.html#JobLibraryExamples", null ],
        [ "Parallel Parameters", "PythonInterface.html#ParallelParameters", null ],
        [ "Performances", "PythonInterface.html#JobLibPerformances", null ]
      ] ],
      [ "Multiple Interpreters", "PythonInterface.html#MultipleInterpreters", null ],
      [ "Master Slave Support", "PythonInterface.html#StarpupyMasterSlave", null ]
    ] ],
    [ "The StarPU OpenMP Runtime Support (SORS)", "OpenMPRuntimeSupport.html", [
      [ "Implementation Details and Specificities", "OpenMPRuntimeSupport.html#OMPImplementation", [
        [ "Main Thread", "OpenMPRuntimeSupport.html#OMPMainThread", null ],
        [ "Extended Task Semantics", "OpenMPRuntimeSupport.html#OMPTaskSemantics", null ]
      ] ],
      [ "Configuration", "OpenMPRuntimeSupport.html#OMPConfiguration", null ],
      [ "Initialization and Shutdown", "OpenMPRuntimeSupport.html#OMPInitExit", null ],
      [ "Parallel Regions and Worksharing", "OpenMPRuntimeSupport.html#OMPSharing", [
        [ "Parallel Regions", "OpenMPRuntimeSupport.html#OMPParallel", null ],
        [ "Parallel For", "OpenMPRuntimeSupport.html#OMPFor", null ],
        [ "Sections", "OpenMPRuntimeSupport.html#OMPSections", null ],
        [ "Single", "OpenMPRuntimeSupport.html#OMPSingle", null ]
      ] ],
      [ "Tasks", "OpenMPRuntimeSupport.html#OMPTask", [
        [ "Explicit Tasks", "OpenMPRuntimeSupport.html#OMPTaskExplicit", null ],
        [ "Data Dependencies", "OpenMPRuntimeSupport.html#OMPDataDependencies", null ],
        [ "TaskWait and TaskGroup", "OpenMPRuntimeSupport.html#OMPTaskSyncs", null ]
      ] ],
      [ "Synchronization Support", "OpenMPRuntimeSupport.html#OMPSynchronization", [
        [ "Simple Locks", "OpenMPRuntimeSupport.html#OMPSimpleLock", null ],
        [ "Nestable Locks", "OpenMPRuntimeSupport.html#OMPNestableLock", null ],
        [ "Critical Sections", "OpenMPRuntimeSupport.html#OMPCritical", null ],
        [ "Barriers", "OpenMPRuntimeSupport.html#OMPBarrier", null ]
      ] ],
      [ "Example: An OpenMP LLVM Support", "OpenMPRuntimeSupport.html#OMPLLVM", null ],
      [ "OpenMP Standard Functions in StarPU", "OpenMPRuntimeSupport.html#OMPStandard", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#a9adac8be1a174cb4ad9d8e68c2ec7678",
"group__API__Data__Interfaces.html#ac01fd0c59e0a5740ab8b000a2681f0aa",
"group__API__Data__Interfaces.html#gafd9d133c4d658b777d9800eba79765b3",
"group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c",
"group__API__MPI__FT__Support.html#ga32a3aa7dc7e387ac0fd7eb89ca11b912",
"group__API__Modularized__Scheduler.html#gae1aa931285a2b952473fc7def121c5cd",
"group__API__Parallel__Worker.html#gadc0266b4a673ad33bb6a39eaf22afc08",
"group__API__Profiling.html#gacf0b5499290848f07c97a32c6c2412db",
"group__API__Scheduling__Policy.html#ga3bf8df94c9ea3f1370b53fff54e72888",
"group__API__Workers.html#ga6312aa4b12ce7e06fe391bcafda6796a",
"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html",
"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html",
"sc__hypervisor__config_8h.html#a002798d04e272d4901e06d2909e2d970"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
